@@ -10,7 +10,7 @@ class Command(BaseCommand):
     help = 'removes old not used verification codes and partials'
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
             '--age',
             action='store',
