@@ -1,9 +1,6 @@
-# -*- coding: utf-8
-from __future__ import unicode_literals, absolute_import
-
 from django.contrib.auth import get_user_model
 from django.test import TestCase
-from social_django.compat import reverse
+from django.urls import reverse
 from social_django.models import UserSocialAuth
 
 
@@ -11,7 +8,7 @@ class SocialAdminTest(TestCase):
     @classmethod
     def setUpTestData(cls):
         User = get_user_model()
-        User.objects.create_superuser(
+        User._default_manager.create_superuser(
             username='admin', email='admin@test.com', first_name='Admin',
             password='super-duper-test'
         )
@@ -26,5 +23,5 @@ class SocialAdminTest(TestCase):
         """The App name in the admin index page"""
         self.client.login(username='admin', password='super-duper-test')
         meta = UserSocialAuth._meta
-        url_name = 'admin:%s_%s_changelist' % (meta.app_label, meta.model_name)
+        url_name = f'admin:{meta.app_label}_{meta.model_name}_changelist'
         self.client.get(reverse(url_name))
